==> CGSocialApp-1.1.10.tar.gz: CGSocialApp/lib/class.cgsa_apikey_perms.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGSocialApp (c) 2011 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE

final class cgsa_apikey_perms
{
  private function __construct() {}

  const PERM_USERS_REGISTER = 'perm_users_register';
  const PERM_USERS_LOGIN    = 'perm_users_login';
  const PERM_USERS_READ     = 'perm_users_read';
  const PERM_USERS_WRITE    = 'perm_users_write';

  const PERM_ACTIVITIES_READ = 'perm_activities_read';

  const PERM_BADGES_READ = 'perm_badges_read';

  const PERM_CHECKINS_READ     = 'perm_checkins_read';
  const PERM_CHECKINS_ADD      = 'perm_checkins_add';
  const PERM_CHECKINS_DEL      = 'perm_checkins_del';
  const PERM_CHECKINS_EDIT     = 'perm_checkins_edit';
  const PERM_CHECKINS_APPROVE = 'perm_checkins_approve';

  const PERM_FRIENDS_READ    = 'perm_friends_read';
  const PERM_FRIENDS_WRITE   = 'perm_friends_write';

  const PERM_LEADERBOARDS_READ = 'perm_leaderboards_read';

  const PERM_LOCATIONS_READ  = 'perm_locations_read';
  const PERM_LOCATIONS_WRITE = 'perm_locations_write';

  const PERM_NOTIFICATION_SEND = 'perm_notification_send';

  const PERM_SOCIAL_READ     = 'perm_social_read';
  const PERM_SOCIAL_WRITE    = 'perm_social_read';
  const PERM_SOCIAL_SEND     = 'perm_social_send';


  public static function get_all_perms()
  {
    $res = array();
    $res[] = self::PERM_USERS_REGISTER;
    $res[] = self::PERM_USERS_LOGIN;
    $res[] = self::PERM_USERS_READ;
    $res[] = self::PERM_USERS_WRITE;
    $res[] = self::PERM_ACTIVITIES_READ;
    $res[] = self::PERM_BADGES_READ;
    $res[] = self::PERM_CHECKINS_READ;
    $res[] = self::PERM_CHECKINS_ADD;
    $res[] = self::PERM_CHECKINS_DEL;
    $res[] = self::PERM_CHECKINS_EDIT;
    $res[] = self::PERM_CHECKINS_APPROVE;
    $res[] = self::PERM_FRIENDS_READ;
    $res[] = self::PERM_FRIENDS_WRITE;
    $res[] = self::PERM_LEADERBOARDS_READ;
    $res[] = self::PERM_LOCATIONS_READ;
    $res[] = self::PERM_LOCATIONS_WRITE;
    $res[] = self::PERM_NOTIFICATION_SEND; // doc this
    $res[] = self::PERM_SOCIAL_READ;  // doc this
    $res[] = self::PERM_SOCIAL_WRITE; // doc this
    $res[] = self::PERM_SOCIAL_SEND;  // doc this
    return $res;
  }

  public static function is_perm($perm)
  {
    if( !in_array($perm,self::get_all_perms()) ) return FALSE;
    return TRUE;
  }

} // end of class

#
# EOF
#
?>

==> CGSocialApp-1.3.1.tar.gz: CGSocialApp/lib/class.cgsa_apikey_perms.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGSocialApp (c) 2011 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE

final class cgsa_apikey_perms
{
  private function __construct() {}

  const PERM_USERS_REGISTER = 'perm_users_register';
  const PERM_USERS_LOGIN    = 'perm_users_login';
  const PERM_USERS_READ     = 'perm_users_read';
  const PERM_USERS_WRITE    = 'perm_users_write';

  const PERM_ACTIVITIES_READ = 'perm_activities_read';

  const PERM_BADGES_READ = 'perm_badges_read';

  const PERM_CHECKINS_READ     = 'perm_checkins_read';
  const PERM_CHECKINS_ADD      = 'perm_checkins_add';
  const PERM_CHECKINS_DEL      = 'perm_checkins_del';
  const PERM_CHECKINS_EDIT     = 'perm_checkins_edit';
  const PERM_CHECKINS_APPROVE = 'perm_checkins_approve';

  const PERM_FRIENDS_READ    = 'perm_friends_read';
  const PERM_FRIENDS_WRITE   = 'perm_friends_write';

  const PERM_LEADERBOARDS_READ = 'perm_leaderboards_read';

  const PERM_LOCATIONS_READ  = 'perm_locations_read';
  const PERM_LOCATIONS_WRITE = 'perm_locations_write';

  const PERM_NOTIFICATION_SEND = 'perm_notification_send';

  const PERM_SOCIAL_READ     = 'perm_social_read';
  const PERM_SOCIAL_WRITE    = 'perm_social_read';
  const PERM_SOCIAL_SEND     = 'perm_social_send';

  const PERM_FAVORITES_READ   = 'perm_favorites_read';
  const PERM_FAVORITES_WRITE  = 'perm_favorites_write';

  public static function get_all_perms()
  {
    $res = array();
    $res[] = self::PERM_USERS_REGISTER;
    $res[] = self::PERM_USERS_LOGIN;
    $res[] = self::PERM_USERS_READ;
    $res[] = self::PERM_USERS_WRITE;
    $res[] = self::PERM_ACTIVITIES_READ;
    $res[] = self::PERM_BADGES_READ;
    $res[] = self::PERM_CHECKINS_READ;
    $res[] = self::PERM_CHECKINS_ADD;
    $res[] = self::PERM_CHECKINS_DEL;
    $res[] = self::PERM_CHECKINS_EDIT;
    $res[] = self::PERM_CHECKINS_APPROVE;
    $res[] = self::PERM_FRIENDS_READ;
    $res[] = self::PERM_FRIENDS_WRITE;
    $res[] = self::PERM_LEADERBOARDS_READ;
    $res[] = self::PERM_LOCATIONS_READ;
    $res[] = self::PERM_LOCATIONS_WRITE;
    $res[] = self::PERM_NOTIFICATION_SEND; // doc this
    $res[] = self::PERM_SOCIAL_READ;  // doc this
    $res[] = self::PERM_SOCIAL_WRITE; // doc this
    $res[] = self::PERM_SOCIAL_SEND;  // doc this
    $res[] = self::PERM_FAVORITES_READ; // doc this
    $res[] = self::PERM_FAVORITES_WRITE; // doc this
    return $res;
  }

  public static function is_perm($perm)
  {
    if( !in_array($perm,self::get_all_perms()) ) return FALSE;
    return TRUE;
  }

} // end of class

#
# EOF
#
?>
